@@ -24,23 +24,28 @@ public class Config {
      */
     private static Properties config = new Properties();
 
+    /**
+     * 改行
+     */
+    public static final String NL = System.getProperty("line.separator");
+
     /////////////////////////////////////////////////////////////////
     // constant field
 
     /**
      * デフォルト設定ファイル名
      */
-    private static final String DEFAULT_CONFIG_FILE_NAME = "bodybuilder-default.properties";
+    protected static final String DEFAULT_CONFIG_FILE_NAME = "bodybuilder-default.properties";
 
     /**
      * 設定ファイル名
      */
-    private static final String CONFIG_FILE_NAME = "bodybuilder.properties";
+    protected static final String CONFIG_FILE_NAME = "bodybuilder.properties";
 
     /**
      * キーのプリフィックス
      */
-    private static final String PROP_KEY_PREFIX = "bodybuilder.";
+    protected static final String PROP_KEY_PREFIX = "bodybuilder.";
 
     /////////////////////////////////////////////////////////////////
     // property
@@ -69,7 +74,7 @@ public class Config {
     /**
      * 検査のプロパティのプリフィックス
      */
-    private static final String INSPECTION_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
+    protected static final String INSPECTION_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
             + "inspection.";
 
     /**
@@ -100,16 +105,6 @@ public class Config {
         return getBooleanProperty(INSPECTION_PROP_KEY_PRIFIX + "class", true);
     }
 
-    /**
-     * 例外のメッセージの検査に正規表現を使用するかどうかを返す。
-     * 
-     * @return 正規表現を使用する場合はtrue
-     */
-    public static boolean isInspectionExceptionRegex() {
-        return getBooleanProperty(INSPECTION_PROP_KEY_PRIFIX
-                + "exception.regex", true);
-    }
-
     /**
      * 例外の原因を検査するかどうかを返す。
      * 
@@ -120,6 +115,15 @@ public class Config {
                 + "exception.cause", false);
     }
 
+    /**
+     * 正規表現で検査するかどうかを返す。
+     * 
+     * @return 検査する場合はtrue
+     */
+    public static boolean isInspectionRegex() {
+        return getBooleanProperty(INSPECTION_PROP_KEY_PRIFIX + "regex", true);
+    }
+
     /**
      * 検査しないプロパティのマップを取得する。
      * 
@@ -131,7 +135,7 @@ public class Config {
         Map ignores = new HashMap();
 
         for (int i = 0; i < cpvals.length; i++) {
-            String[] divided = cpvals[i].split("[#/]");
+            String[] divided = cpvals[i].split("[|/]");
             List props = new ArrayList(Arrays.asList(divided));
             props.remove(0);
             ignores.put(divided[0], props);
@@ -146,7 +150,7 @@ public class Config {
     /**
      * ビューのプロパティのプリフィックス
      */
-    private static final String VIEW_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
+    protected static final String VIEW_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
             + "view.";
 
     /**
@@ -164,7 +168,7 @@ public class Config {
     /**
      * ビルダーのプロパティのプリフィックス
      */
-    private static final String BUILDER_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
+    protected static final String BUILDER_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
             + "builder.";
 
     /**
@@ -182,7 +186,7 @@ public class Config {
     /**
      * ビューアのプロパティのプリフィックス
      */
-    private static final String VIEWER_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
+    protected static final String VIEWER_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
             + "viewer.";
 
     /**
@@ -200,7 +204,7 @@ public class Config {
     /**
      * インスペクターのプロパティのプリフィックス
      */
-    private static final String INSPECTOR_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
+    protected static final String INSPECTOR_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
             + "inspector.";
 
     /**
@@ -218,7 +222,7 @@ public class Config {
     /**
      * 拡張値のプロパティのプリフィックス
      */
-    private static final String VALUE_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
+    protected static final String VALUE_PROP_KEY_PRIFIX = PROP_KEY_PREFIX
             + "value.";
 
     /**
@@ -236,7 +240,7 @@ public class Config {
     /**
      * テストのプロパティのプリフィックス
      */
-    private static final String TEST_PROP_KEY_PREFIX = PROP_KEY_PREFIX
+    protected static final String TEST_PROP_KEY_PREFIX = PROP_KEY_PREFIX
             + "test.";
 
     /**
@@ -296,7 +300,7 @@ public class Config {
     /**
      * データベースのプロパティのプリフィックス
      */
-    private static final String DATABASE_PROP_KEY_PREFIX = PROP_KEY_PREFIX
+    protected static final String DATABASE_PROP_KEY_PREFIX = PROP_KEY_PREFIX
             + "database.";
 
     /**
@@ -344,6 +348,17 @@ public class Config {
         return subMap(DATABASE_PROP_KEY_PREFIX + "dataset.");
     }
 
+    // TODO 削除すること。
+    /**
+     * Excelのデータをトリムするかどうかを返す。
+     * 
+     * @return トリムする場合はtrue
+     * @deprecated
+     */
+    public static boolean isXlsTrim() {
+        return getBooleanProperty(DATABASE_PROP_KEY_PREFIX + "xlstrim", false);
+    }
+
     /////////////////////////////////////////////////////////////////
     // property utility
 
